@@ -1,10 +1,10 @@
 use strict;
 use warnings;
-package Test::JSON::Schema::Acceptance; # git description: v1.029-4-gec574f1
+package Test::JSON::Schema::Acceptance; # git description: v1.030-2-g7347423
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Acceptance testing for JSON-Schema based validators
 
-our $VERSION = '1.030';
+our $VERSION = '1.031';
 
 use 5.020;
 use Moo;
@@ -551,7 +551,7 @@ Test::JSON::Schema::Acceptance - Acceptance testing for JSON-Schema based valida
 
 =head1 VERSION
 
-version 1.030
+version 1.031
 
 =head1 SYNOPSIS
 
@@ -564,7 +564,7 @@ modules that run the same tests in different languages.
 
 In the JSON::Schema::Modern module, a test could look like the following:
 
-  use Test::More;
+  use Test2::V0;
   use JSON::Schema::Modern;
   use Test::JSON::Schema::Acceptance;
 
